emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/corfu 8455863 2/3: Check if further completion is possi


From: ELPA Syncer
Subject: [elpa] externals/corfu 8455863 2/3: Check if further completion is possible
Date: Sun, 21 Nov 2021 12:57:12 -0500 (EST)

branch: externals/corfu
commit 845586319da7e9361c672c87a9fd73f0b069376b
Author: Daniel Mendler <mail@daniel-mendler.de>
Commit: Daniel Mendler <mail@daniel-mendler.de>

    Check if further completion is possible
---
 corfu.el | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/corfu.el b/corfu.el
index 7130c87..3adaa5f 100644
--- a/corfu.el
+++ b/corfu.el
@@ -757,9 +757,11 @@ input. If there hasn't been any input, then quit."
      ((and initializing (not corfu--candidates))
       (funcall msg "No match")
       (corfu-quit))
-     ;; 2) Single matching candidate
-     ((and (not (equal str "")) (equal corfu--candidates (list str)))
-      (corfu--done str 'exact))
+     ;; 2) Single matching candidate and no further completion is possible
+     ((and (not (equal str ""))
+           (equal corfu--candidates (list str))
+           (not (consp (completion-try-completion str table pred pt 
corfu--metadata))))
+      (corfu--done str 'finished))
      ;; 3) There exist candidates
      ;; &  Input is non-empty or continue command
      ;; => Show candidates popup



reply via email to

[Prev in Thread] Current Thread [Next in Thread]